@@ -11,6 +11,7 @@ from ast import And as NodeAnd
 from ast import AnnAssign as NodeAnnAssign
 from ast import Assign as NodeAssign
 from ast import Attribute as NodeAttribute
+from ast import AugAssign as NodeAugAssign
 from ast import BinOp as NodeBinOp
 from ast import BitAnd as NodeBitAnd
 from ast import BitOr as NodeBitOr
@@ -78,6 +79,9 @@ from typing import TYPE_CHECKING, Any, Callable, Sequence, Type
 from griffe.collections import LinesCollection
 from griffe.exceptions import LastNodeError, RootNodeError
 from griffe.expressions import Expression, Name
+from griffe.logger import get_logger
+
+logger = get_logger(__name__)
 
 # TODO: remove once Python 3.7 support is dropped
 if sys.version_info < (3, 8):
@@ -523,31 +527,76 @@ def _join(sequence, item):
     return new_sequence
 
 
+def _parse__all__constant(node: NodeConstant, parent: Module) -> list[str]:
+    try:
+        return [node.value]
+    except AttributeError:
+        return [node.s]  # TODO: remove once Python 3.7 is dropped
+
+
+def _parse__all__name(node: NodeName, parent: Module) -> list[Name]:
+    return [Name(node.id, partial(parent.resolve, node.id))]
+
+
+def _parse__all__starred(node: NodeStarred, parent: Module) -> list[str | Name]:
+    return _parse__all__(node.value, parent)
+
+
+def _parse__all__sequence(node: NodeList | NodeSet | NodeTuple, parent: Module) -> list[str | Name]:
+    sequence = []
+    for elt in node.elts:
+        sequence.extend(_parse__all__(elt, parent))
+    return sequence
+
+
+def _parse__all__binop(node: NodeBinOp, parent: Module) -> list[str | Name]:
+    left = _parse__all__(node.left, parent)
+    right = _parse__all__(node.right, parent)
+    return left + right
+
+
+_node__all__map: dict[Type, Callable[[Any, Module], list[str | Name]]] = {  # noqa: WPS234
+    NodeConstant: _parse__all__constant,  # type: ignore[dict-item]
+    NodeName: _parse__all__name,  # type: ignore[dict-item]
+    NodeStarred: _parse__all__starred,
+    NodeList: _parse__all__sequence,
+    NodeSet: _parse__all__sequence,
+    NodeTuple: _parse__all__sequence,
+    NodeBinOp: _parse__all__binop,
+}
+
+# TODO: remove once Python 3.7 support is dropped
 if sys.version_info < (3, 8):
 
-    def parse__all__(node: NodeAssign) -> set[str]:  # noqa: WPS116,WPS120
-        """Get the values declared in `__all__`.
+    def _parse__all__nameconstant(node: NodeNameConstant, parent: Module) -> list[Name]:
+        return [node.value]
 
-        Parameters:
-            node: The assignment node.
+    def _parse__all__str(node: NodeStr, parent: Module) -> list[str]:
+        return [node.s]
 
-        Returns:
-            A set of names.
-        """
-        return {elt.s for elt in node.value.elts}  # type: ignore[attr-defined]
+    _node__all__map[NodeNameConstant] = _parse__all__nameconstant  # type: ignore[assignment]
+    _node__all__map[NodeStr] = _parse__all__str  # type: ignore[assignment]
 
-else:
 
-    def parse__all__(node: NodeAssign) -> set[str]:  # noqa: WPS116,WPS120,WPS440
-        """Get the values declared in `__all__`.
+def _parse__all__(node: AST, parent: Module) -> list[str | Name]:
+    return _node__all__map[type(node)](node, parent)
 
-        Parameters:
-            node: The assignment node.
 
-        Returns:
-            A set of names.
-        """
-        return {elt.value for elt in node.value.elts}  # type: ignore[attr-defined]
+def parse__all__(node: NodeAssign | NodeAugAssign, parent: Module) -> list[str | Name]:  # noqa: WPS120,WPS440
+    """Get the values declared in `__all__`.
+
+    Parameters:
+        node: The assignment node.
+        parent: The parent module.
+
+    Returns:
+        A set of names.
+    """
+    try:
+        return _parse__all__(node.value, parent)
+    except KeyError as error:
+        logger.debug(f"Cannot parse __all__ assignment: {get_value(node.value)} ({error})")
+        return []
 
 
 # ==========================================================
@@ -577,8 +626,8 @@ def _get_bitor_annotation(node: NodeBitOr, parent: Module | Class) -> str:
 
 
 def _get_call_annotation(node: NodeCall, parent: Module | Class) -> Expression:
-    posargs = Expression(*[_get_annotation(arg, parent) for arg in node.args])
-    kwargs = Expression(*[_get_annotation(kwarg, parent) for kwarg in node.keywords])
+    posargs = Expression(*_join([_get_annotation(arg, parent) for arg in node.args], ", "))
+    kwargs = Expression(*_join([_get_annotation(kwarg, parent) for kwarg in node.keywords], ", "))
     args: Expression | str
     if posargs and kwargs:
         args = Expression(posargs, ", ", kwargs)
@@ -613,6 +662,10 @@ def _get_invert_annotation(node: NodeInvert, parent: Module | Class) -> str:
     return "~"
 
 
+def _get_keyword_annotation(node: NodeKeyword, parent: Module | Class) -> Expression:
+    return Expression(f"{node.arg}=", _get_annotation(node.value, parent))
+
+
 def _get_list_annotation(node: NodeList, parent: Module | Class) -> Expression:
     return Expression("[", *_join([_get_annotation(el, parent) for el in node.elts], ", "), "]")
 
@@ -635,6 +688,14 @@ def _get_unaryop_annotation(node: NodeUnaryOp, parent: Module | Class) -> Expres
     return Expression(_get_annotation(node.op, parent), _get_annotation(node.operand, parent))
 
 
+def _get_uadd_annotation(node: NodeUAdd, parent: Module | Class) -> str:
+    return "+"
+
+
+def _get_usub_annotation(node: NodeUSub, parent: Module | Class) -> str:
+    return "-"
+
+
 _node_annotation_map: dict[Type, Callable[[Any, Module | Class], str | Name | Expression]] = {
     NodeAttribute: _get_attribute_annotation,
     NodeBinOp: _get_binop_annotation,
@@ -645,11 +706,14 @@ _node_annotation_map: dict[Type, Callable[[Any, Module | Class], str | Name | Ex
     NodeEllipsis: _get_ellipsis_annotation,
     NodeIfExp: _get_ifexp_annotation,
     NodeInvert: _get_invert_annotation,
+    NodeKeyword: _get_keyword_annotation,
     NodeList: _get_list_annotation,
     NodeName: _get_name_annotation,
     NodeSubscript: _get_subscript_annotation,
     NodeTuple: _get_tuple_annotation,
     NodeUnaryOp: _get_unaryop_annotation,
+    NodeUAdd: _get_uadd_annotation,
+    NodeUSub: _get_usub_annotation,
 }
 
 # TODO: remove once Python 3.8 support is dropped
@@ -663,13 +727,21 @@ if sys.version_info < (3, 9):
 # TODO: remove once Python 3.7 support is dropped
 if sys.version_info < (3, 8):
 
-    def _get_nameconstant_annotation(node: NodeNameConstant, parent: Module | Class) -> str | Name | Expression:
+    def _get_bytes_annotation(node: NodeBytes, parent: Module | Class) -> str:
+        return repr(node.s)
+
+    def _get_nameconstant_annotation(node: NodeNameConstant, parent: Module | Class) -> str:
         return repr(node.value)
 
+    def _get_num_annotation(node: NodeNum, parent: Module | Class) -> str:
+        return repr(node.n)
+
     def _get_str_annotation(node: NodeStr, parent: Module | Class) -> str:
         return node.s
 
+    _node_annotation_map[NodeBytes] = _get_bytes_annotation
     _node_annotation_map[NodeNameConstant] = _get_nameconstant_annotation
+    _node_annotation_map[NodeNum] = _get_num_annotation
     _node_annotation_map[NodeStr] = _get_str_annotation
 
 
@@ -723,8 +795,6 @@ def get_docstring(
 
 # ==========================================================
 # values
-
-
 def _get_add_value(node: NodeAdd) -> str:
     return "+"
 
@@ -738,11 +808,11 @@ def _get_arguments_value(node: NodeArguments) -> str:
 
 
 def _get_attribute_value(node: NodeAttribute) -> str:
-    return f"{get_value(node.value)}.{node.attr}"
+    return f"{_get_value(node.value)}.{node.attr}"
 
 
 def _get_binop_value(node: NodeBinOp) -> str:
-    return f"{get_value(node.left)} {get_value(node.op)} {get_value(node.right)}"
+    return f"{_get_value(node.left)} {_get_value(node.op)} {_get_value(node.right)}"
 
 
 def _get_bitor_value(node: NodeBitOr) -> str:
@@ -758,12 +828,12 @@ def _get_bitxor_value(node: NodeBitXor) -> str:
 
 
 def _get_boolop_value(node: NodeBoolOp) -> str:
-    return get_value(node.op).join(get_value(value) for value in node.values)
+    return _get_value(node.op).join(_get_value(value) for value in node.values)
 
 
 def _get_call_value(node: NodeCall) -> str:
-    posargs = ", ".join(get_value(arg) for arg in node.args)
-    kwargs = ", ".join(get_value(kwarg) for kwarg in node.keywords)
+    posargs = ", ".join(_get_value(arg) for arg in node.args)
+    kwargs = ", ".join(_get_value(kwarg) for kwarg in node.keywords)
     if posargs and kwargs:
         args = f"{posargs}, {kwargs}"
     elif posargs:
@@ -772,20 +842,20 @@ def _get_call_value(node: NodeCall) -> str:
         args = kwargs
     else:
         args = ""
-    return f"{get_value(node.func)}({args})"
+    return f"{_get_value(node.func)}({args})"
 
 
 def _get_compare_value(node: NodeCompare) -> str:
-    left = get_value(node.left)
-    ops = [get_value(op) for op in node.ops]
-    comparators = [get_value(comparator) for comparator in node.comparators]
+    left = _get_value(node.left)
+    ops = [_get_value(op) for op in node.ops]
+    comparators = [_get_value(comparator) for comparator in node.comparators]
     return f"{left} " + " ".join(f"{op} {comp}" for op, comp in zip(ops, comparators))
 
 
 def _get_comprehension_value(node: NodeComprehension) -> str:
-    target = get_value(node.target)
-    iterable = get_value(node.iter)
-    conditions = [get_value(condition) for condition in node.ifs]
+    target = _get_value(node.target)
+    iterable = _get_value(node.iter)
+    conditions = [_get_value(condition) for condition in node.ifs]
     value = f"for {target} in {iterable}"
     if conditions:
         value = f"{value} if " + " if ".join(conditions)
@@ -798,20 +868,22 @@ def _get_constant_value(node: NodeConstant) -> str:
     return repr(node.value)
 
 
-def _get_constant_value_no_repr(node: NodeConstant) -> str:
-    return node.value
+def _get_constant_value_no_string_repr(node: NodeConstant) -> str:
+    if isinstance(node.value, str):
+        return node.value
+    return repr(node.value)
 
 
 def _get_dict_value(node: NodeDict) -> str:
     pairs = zip(node.keys, node.values)
-    gen = (f"{'None' if key is None else get_value(key)}: {get_value(value)}" for key, value in pairs)  # noqa: WPS509
+    gen = (f"{'None' if key is None else _get_value(key)}: {_get_value(value)}" for key, value in pairs)  # noqa: WPS509
     return "{" + ", ".join(gen) + "}"
 
 
 def _get_dictcomp_value(node: NodeDictComp) -> str:
-    key = get_value(node.key)
-    value = get_value(node.value)
-    generators = [get_value(gen) for gen in node.generators]
+    key = _get_value(node.key)
+    value = _get_value(node.value)
+    generators = [_get_value(gen) for gen in node.generators]
     return f"{{{key}: {value} " + " ".join(generators) + "}"
 
 
@@ -832,12 +904,12 @@ def _get_floordiv_value(node: NodeFloorDiv) -> str:
 
 
 def _get_formatted_value(node: NodeFormattedValue) -> str:
-    return f"{{{get_value(node.value)}}}"
+    return f"{{{_get_value(node.value)}}}"
 
 
 def _get_generatorexp_value(node: NodeGeneratorExp) -> str:
-    element = get_value(node.elt)
-    generators = [get_value(gen) for gen in node.generators]
+    element = _get_value(node.elt)
+    generators = [_get_value(gen) for gen in node.generators]
     return f"{element} " + " ".join(generators)
 
 
@@ -850,7 +922,7 @@ def _get_gt_value(node: NodeNotEq) -> str:
 
 
 def _get_ifexp_value(node: NodeIfExp) -> str:
-    return f"{get_value(node.body)} if {get_value(node.test)} else {get_value(node.orelse)}"
+    return f"{_get_value(node.body)} if {_get_value(node.test)} else {_get_value(node.orelse)}"
 
 
 def _get_invert_value(node: NodeInvert) -> str:
@@ -870,27 +942,27 @@ def _get_isnot_value(node: NodeIsNot) -> str:
 
 
 def _get_joinedstr_value(node: NodeJoinedStr) -> str:
-    _node_value_map[NodeConstant] = _get_constant_value_no_repr
-    result = repr("".join(get_value(value) for value in node.values))
+    _node_value_map[NodeConstant] = _get_constant_value_no_string_repr
+    result = "f" + repr("".join(_get_value(value) for value in node.values))
     _node_value_map[NodeConstant] = _get_constant_value
     return result
 
 
 def _get_keyword_value(node: NodeKeyword) -> str:
-    return f"{node.arg}={get_value(node.value)}"
+    return f"{node.arg}={_get_value(node.value)}"
 
 
 def _get_lambda_value(node: NodeLambda) -> str:
-    return f"lambda {get_value(node.args)}: {get_value(node.body)}"
+    return f"lambda {_get_value(node.args)}: {_get_value(node.body)}"
 
 
 def _get_list_value(node: NodeList) -> str:
-    return "[" + ", ".join(get_value(el) for el in node.elts) + "]"
+    return "[" + ", ".join(_get_value(el) for el in node.elts) + "]"
 
 
 def _get_listcomp_value(node: NodeListComp) -> str:
-    element = get_value(node.elt)
-    generators = [get_value(gen) for gen in node.generators]
+    element = _get_value(node.elt)
+    generators = [_get_value(gen) for gen in node.generators]
     return f"[{element} " + " ".join(generators) + "]"
 
 
@@ -947,24 +1019,24 @@ def _get_rshift_value(node: NodeRShift) -> str:
 
 
 def _get_set_value(node: NodeSet) -> str:
-    return "{" + ", ".join(get_value(el) for el in node.elts) + "}"
+    return "{" + ", ".join(_get_value(el) for el in node.elts) + "}"
 
 
 def _get_setcomp_value(node: NodeSetComp) -> str:
-    element = get_value(node.elt)
-    generators = [get_value(gen) for gen in node.generators]
+    element = _get_value(node.elt)
+    generators = [_get_value(gen) for gen in node.generators]
     return f"{{{element} " + " ".join(generators) + "}"
 
 
 def _get_slice_value(node: NodeSlice) -> str:
-    value = f"{get_value(node.lower) if node.lower else ''}:{get_value(node.upper) if node.upper else ''}"
+    value = f"{_get_value(node.lower) if node.lower else ''}:{_get_value(node.upper) if node.upper else ''}"
     if node.step:
-        value = f"{value}:{get_value(node.step)}"
+        value = f"{value}:{_get_value(node.step)}"
     return value
 
 
 def _get_starred_value(node: NodeStarred) -> str:
-    return get_value(node.value)
+    return _get_value(node.value)
 
 
 def _get_sub_value(node: NodeSub) -> str:
@@ -972,14 +1044,14 @@ def _get_sub_value(node: NodeSub) -> str:
 
 
 def _get_subscript_value(node: NodeSubscript) -> str:
-    subscript = get_value(node.slice)
+    subscript = _get_value(node.slice)
     if isinstance(subscript, str):
         subscript = subscript.strip("()")
-    return f"{get_value(node.value)}[{subscript}]"
+    return f"{_get_value(node.value)}[{subscript}]"
 
 
 def _get_tuple_value(node: NodeTuple) -> str:
-    return "(" + ", ".join(get_value(el) for el in node.elts) + ")"
+    return "(" + ", ".join(_get_value(el) for el in node.elts) + ")"
 
 
 def _get_uadd_value(node: NodeUAdd) -> str:
@@ -987,7 +1059,7 @@ def _get_uadd_value(node: NodeUAdd) -> str:
 
 
 def _get_unaryop_value(node: NodeUnaryOp) -> str:
-    return f"{get_value(node.op)}{get_value(node.operand)}"
+    return f"{_get_value(node.op)}{_get_value(node.operand)}"
 
 
 def _get_usub_value(node: NodeUSub) -> str:
@@ -997,11 +1069,11 @@ def _get_usub_value(node: NodeUSub) -> str:
 def _get_yield_value(node: NodeYield) -> str:
     if node.value is None:
         return repr(None)
-    return get_value(node.value)
+    return _get_value(node.value)
 
 
 _node_value_map: dict[Type, Callable[[Any], str]] = {
-    type(None): lambda _: repr(None),
+    # type(None): lambda _: repr(None),
     NodeAdd: _get_add_value,
     NodeAnd: _get_and_value,
     NodeArguments: _get_arguments_value,
@@ -1065,7 +1137,7 @@ _node_value_map: dict[Type, Callable[[Any], str]] = {
 if sys.version_info < (3, 9):
 
     def _get_index_value(node: NodeIndex) -> str:
-        return get_value(node.value)
+        return _get_value(node.value)
 
     _node_value_map[NodeIndex] = _get_index_value
 
@@ -1091,7 +1163,11 @@ if sys.version_info < (3, 8):
     _node_value_map[NodeStr] = _get_str_value
 
 
-def get_value(node: AST) -> str:
+def _get_value(node: AST) -> str:
+    return _node_value_map[type(node)](node)
+
+
+def get_value(node: AST | None) -> str | None:
     """Extract a complex value as a string.
 
     Parameters:
@@ -1100,6 +1176,8 @@ def get_value(node: AST) -> str:
     Returns:
         The unparsed code of the node.
     """
+    if node is None:
+        return None
     return _node_value_map[type(node)](node)
 
 
@@ -1188,7 +1266,7 @@ def get_parameter_default(node: AST, filepath: Path, lines_collection: LinesColl
     if node is None:
         return None
     with suppress(KeyError):
-        return get_value(node)
+        return _get_value(node)
     if node.lineno == node.end_lineno:  # type: ignore[attr-defined]
         return lines_collection[filepath][node.lineno - 1][node.col_offset : node.end_col_offset]  # type: ignore[attr-defined]
     # TODO: handle multiple line defaults
